summaryrefslogtreecommitdiffstats
path: root/languages/cpp/app_templates/kicker/applet.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'languages/cpp/app_templates/kicker/applet.cpp')
-rw-r--r--languages/cpp/app_templates/kicker/applet.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/languages/cpp/app_templates/kicker/applet.cpp b/languages/cpp/app_templates/kicker/applet.cpp
index 29ec3d1d..d609fa26 100644
--- a/languages/cpp/app_templates/kicker/applet.cpp
+++ b/languages/cpp/app_templates/kicker/applet.cpp
@@ -10,8 +10,8 @@
#include "%{APPNAMELC}.h"
-%{APPNAME}::%{APPNAME}(const TQString& configFile, Type type, int actions, TQWidget *parent, const char *name)
- : KPanelApplet(configFile, type, actions, parent, name)
+%{APPNAME}::%{APPNAME}(const TQString& configFile, Type type, int actions, TQWidget *tqparent, const char *name)
+ : KPanelApplet(configFile, type, actions, tqparent, name)
{
// Get the current application configuration handle
ksConfig = config();
@@ -62,11 +62,11 @@ void %{APPNAME}::resizeEvent(TQResizeEvent *e)
extern "C"
{
- KPanelApplet* init( TQWidget *parent, const TQString& configFile)
+ KPanelApplet* init( TQWidget *tqparent, const TQString& configFile)
{
KGlobal::locale()->insertCatalogue("%{APPNAMELC}");
return new %{APPNAME}(configFile, KPanelApplet::Normal,
KPanelApplet::About | KPanelApplet::Help | KPanelApplet::Preferences,
- parent, "%{APPNAMELC}");
+ tqparent, "%{APPNAMELC}");
}
}